#!/usr/bin/env python

from __future__ import print_function, unicode_literals, absolute_import


import sys
import os
import time
import shutil

import thunderbird
from mozprofile import MozillaProfileLock
if sys.platform == 'darwin':
    from platform_macOS import thunderbird_base
elif sys.platform == 'win32':
    from platform_Windows import thunderbird_base
else:
    from platform_Linux import thunderbird_base


P = os.path.join
E = os.path.exists
D = os.path.isdir
N = os.path.basename


def install_xpi(script_dir, profile):
    src = P(script_dir, 'pEp4Tb@pEp.security.xpi')
    dstdir = P(profile, 'extensions')
    dst = P(dstdir, 'pEp4Tb@pEp.security.xpi')
    os.makedirs(dstdir, exist_ok=True)
    shutil.copy2(src, dst)

def clear_startupcache(profile):
    # TODO: find a more portable solution for this (might involve XDG_CACHE?)
    cachepath = profile.replace("/.thunderbird/", "/.cache/thunderbird/")
    startupcache = P(cachepath, "startupCache")
    if D(startupcache):
        print("Clearing startupCache at", cachepath)
        shutil.rmtree(startupcache)
    else:
        print("!!! startupCache not found, not cleared")

def main():
    script_dir = sys.argv[1]
    del sys.argv[1]
    profile = thunderbird.profile_path(thunderbird_base)
    print("Importing into profile", profile)
    tb_profile_lock = MozillaProfileLock(profile)
    for retry in range(1, 37):  # retry for 3 minutes
        if tb_profile_lock.lock():
            break
        print("-!- Thunderbird profile is locked: "
              "is Thunderbird still running? (retry {0}/37)".format(retry))
        time.sleep(5)
    if not tb_profile_lock.haveLock:
        print("!!! Stopping with error due to persistent error")
        sys.exit(1)
    install_xpi(script_dir, profile)
    clear_startupcache(profile)
    # Import the trigger-happy original module:
    import pEp_import

if __name__ == "__main__":
    sys.exit(main())
