#!/bin/bash

exec > pEp-install.log 2>&1

echo "$@"
set -x

# Unzip is much more rare than one would hope, so we need a bunch of alternatives.

try_unzip() {
  unzip "$1"
}

try_untar() {
  tar -xf "$1"
}

try_bsdtar() {
  bsdtar -xf "$1"
}

try_pyzip() {
  python -m zipfile -e "$1" .
}


# Try to execute an installer in the usual pEp installer format.

try_run() {
  mkdir -p install_$$
  cd install_$$
  try_unzip ../"$1" || try_bsdtar ../"$1" || try_untar ../"$1" || try_pyzip ../"$1" || return 1
  if [ -f */install.run ]; then
    set -e
    cd $(dirname */install.run)
    # the parent will be killed in the process, we need to survive.
    # systemd actually makes this very hard. We need "KillMode=process" in the
    # updater service to have any chance of surviving.
    nohup sh -c "./install.run ; cd ../.. ; rm -rf install_$$" &
    return 0
  fi
  cd ../..
  rm -rf install_$$
  return 1
}

# TODO: next, we should try to find some system way to open things. Think xdg-open.

# Or, we just launch a browser. Browsers are typically quite good at opening
# arbitrary files, it might just need a slightly confusing intermediate dialog.

try_firefox() {
  firefox "$1"
}

try_browser() {
  # This actually calls xdg-open, which can fail silently.
  python -m webbrowser "$1"
}

try_open() {
  # give priority to FF if we have it, since we know it works.
  try_firefox "$1" || try_browser "$1"
}

if [[ $1 == *.zip ]]; then
  try_run "$1" && exit 0
fi

try_open "$1" && exit 0

exit 1
